@@ -405,7 +405,7 @@ def to_datetime_str(s: Any = None,
         iso_str = r_s.isoformat()
         if '.' not in iso_str:
             # '2025-10-09T10:52:41+08:00'
-            iso_str = iso_str[0:-6] + iso_str[-6:]
+            return iso_str
         parts = iso_str.split('.')
         time_zone_part = parts[1]
         time_zone_str = tz
