@@ -14,6 +14,7 @@ def query_sls_logs(logstore_name: str = '',
                    limit: int = 500,
                    query: str = '',
                    query_sql: str = None,
+                   replace_n_t=True,
                    config_name: str = '',
                    country: str = '',
                    start_time: datetime | str | None = None,
@@ -22,7 +23,8 @@ def query_sls_logs(logstore_name: str = '',
                    default_tz: str = '+07:00') -> None:
     """
         query:
-        query_sql: 当有 query_sql 的时候 query 就会被 覆盖
+        query_sql  : 当有 query_sql 的时候 query 就会被 覆盖
+        replace_n_t: 转义 \n, \t 这些符号
     """
     if start_time is None and end_time is None:
         start_time, end_time = (t[0], t[1]) if (t := get_from_txt()) and t[0] is not None else (get_timestamp() - 60 * minute, get_timestamp())
@@ -42,7 +44,9 @@ def query_sls_logs(logstore_name: str = '',
     logs = response.get_logs()
     log_set = set()
     for log in logs:
-        if (msg := clean_up_msg(get_log_msg(log.contents, default_tz=default_tz), clean_up_type=clean_up_msg_type)) is not None:
+        if (
+                msg := clean_up_msg(get_log_msg(log.contents, replace_n_t=replace_n_t, default_tz=default_tz),
+                                    clean_up_type=clean_up_msg_type)) is not None:
             log_set.add(msg)
     log_list = list(log_set)
     log_list.sort()
@@ -53,6 +57,7 @@ def query_sls_logs(logstore_name: str = '',
 
 
 def search_lts_logs(keywords: str | None = '',
+                    replace_n_t=True,
                     limit: int = 500,
                     minute: int = 600,
                     containerName: str = '',
@@ -96,7 +101,8 @@ def search_lts_logs(keywords: str | None = '',
     if logs and logs.logs:
         log_set = set()
         for log in logs.logs[::-1]:
-            if (msg := clean_up_msg(get_log_msg(json.loads(str(log)), default_tz=default_tz), clean_up_type=clean_up_msg_type)) is not None:
+            if (msg := clean_up_msg(get_log_msg(json.loads(str(log)), replace_n_t=replace_n_t, default_tz=default_tz),
+                                    clean_up_type=clean_up_msg_type)) is not None:
                 log_set.add(msg)
         log_list = list(log_set)
         log_list.sort()
